@@ -17,8 +17,7 @@ tabPanel('Scatter Plots', value = 'tab_rfm_scatter',
 			br(),
 			column(2),
 			column(8, align = 'center', 
-				plotOutput('plot_scatter_1', height = '500px') %>% 
-				  withSpinner()
+				plotOutput('plot_scatter_1', height = '500px')
 			),
 			column(2)
 
@@ -30,8 +29,7 @@ tabPanel('Scatter Plots', value = 'tab_rfm_scatter',
 			br(),
 			column(2),
 			column(8, align = 'center', 
-				plotOutput('plot_scatter_2', height = '500px') %>% 
-				  withSpinner()
+				plotOutput('plot_scatter_2', height = '500px')
 			),
 			column(2)
 
@@ -43,8 +41,7 @@ tabPanel('Scatter Plots', value = 'tab_rfm_scatter',
 			br(),
 			column(2),
 			column(8, align = 'center', 
-				plotOutput('plot_scatter_3', height = '500px') %>% 
-				  withSpinner()
+				plotOutput('plot_scatter_3', height = '500px')
 			),
 			column(2)
 		)
